==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Stowarzyszone udostępnianie",
    "Invalid Federated Cloud ID" : "Niewłaściwe ID stowarzyszonej chmury",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "File is already shared with %s" : "Plik jest już współdzielony z %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Współdzielenie %s nie powiodło się, nie można odnaleźć %s. Prawdopobnie serwer nie jest teraz osiągalny.",
    "Accept" : "Akceptuj",
    "Decline" : "Odmów",
    "Federated Cloud Sharing" : "Współdzielenie przez chmurę stowarzyszoną",
    "Open documentation" : "Otwórz dokumentację",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom tego serwera na wysyłanie udziałów do innych serwerów",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom tego serwera na przyjmowanie udziałów z innych serwerów",
    "Federated Cloud" : "Chmura stowarzyszona",
    "Your Federated Cloud ID:" : "ID Twojej stowarzyszonej chmury:",
    "Share it:" : "Współdziel to:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via ownCloud" : "Współdziel ze mną przez ownCloud",
    "HTML Code:" : "Kod HTML:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/pl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Stowarzyszone udostępnianie",
    "Invalid Federated Cloud ID" : "Niewłaściwe ID stowarzyszonej chmury",
    "Sharing %s failed, because this item is already shared with %s" : "Współdzielenie %s nie powiodło się, ponieważ element jest już współdzielony z %s",
    "File is already shared with %s" : "Plik jest już współdzielony z %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Współdzielenie %s nie powiodło się, nie można odnaleźć %s. Prawdopobnie serwer nie jest teraz osiągalny.",
    "Accept" : "Akceptuj",
    "Decline" : "Odmów",
    "Federated Cloud Sharing" : "Współdzielenie przez chmurę stowarzyszoną",
    "Open documentation" : "Otwórz dokumentację",
    "Allow users on this server to send shares to other servers" : "Zezwalaj użytkownikom tego serwera na wysyłanie udziałów do innych serwerów",
    "Allow users on this server to receive shares from other servers" : "Zezwalaj użytkownikom tego serwera na przyjmowanie udziałów z innych serwerów",
    "Federated Cloud" : "Chmura stowarzyszona",
    "Your Federated Cloud ID:" : "ID Twojej stowarzyszonej chmury:",
    "Share it:" : "Współdziel to:",
    "Add to your website" : "Dodaj do swojej strony",
    "Share with me via ownCloud" : "Współdziel ze mną przez ownCloud",
    "HTML Code:" : "Kod HTML:",
    "Add to your ownCloud" : "Dodaj do twojego ownCloud"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
